package com.bank.it.payees.controller;

import com.bank.it.payees.dto.request.PayeeRequest;
import com.bank.it.payees.dto.response.PayeeResponse;
import com.bank.it.payees.service.IManagePayeeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping("/payees/v1")
@Slf4j
public class PayeeController {

    @Autowired
    private IManagePayeeService managePayeeService;

    /**
     * Request to add new payee
     *
     * @param payeeRequest
     * @return PayeeResponse
     */
    @PostMapping("/manage/addPayee")
    public ResponseEntity<PayeeResponse> addPayee(@RequestBody @Valid PayeeRequest payeeRequest) {
        log.info("Entered Add Payee "+PayeeController.class);
        PayeeResponse payeeResponse = managePayeeService.savePayee(payeeRequest);
        return new ResponseEntity<>(payeeResponse, HttpStatus.CREATED);

    }

    /**
     * Request to add update payee
     *
     * @param payeeRequest
     * @return PayeeResponse
     */

    @PutMapping("/manage/updatePayee")
    public ResponseEntity<PayeeResponse> updatePayee(@RequestBody @Valid PayeeRequest payeeRequest) {
        log.info("Entered Update Payee "+PayeeController.class);
        PayeeResponse payeeResponse = managePayeeService.updatePayee(payeeRequest);
        return new ResponseEntity<>(payeeResponse, HttpStatus.ACCEPTED);

    }

    /**
     * Request to retrieve all payees
     *
     * @param
     * @return List of PayeeResponse (Payees)
     */
    @GetMapping("/manage/all")
    public ResponseEntity<List<PayeeResponse>> findPayees() {
        log.info("Entered findPayees "+PayeeController.class);
        List<PayeeResponse> listOfPayees = managePayeeService.searchPayees();
        return new ResponseEntity<List<PayeeResponse>>(listOfPayees, HttpStatus.ACCEPTED);
    }

    /**
     * Request to retrieve payee based on valid accountNumber
     *
     * @param accountNumber
     * @return PayeeResponse
     */

    @GetMapping("/manage/payee/{accountNumber}")
    public ResponseEntity<PayeeResponse> findPayee(@PathVariable int accountNumber) {
        log.info("Entered findPayee "+PayeeController.class);
        PayeeResponse payeeResponse = managePayeeService.searchPayee(accountNumber);
        return new ResponseEntity<PayeeResponse>(payeeResponse, HttpStatus.ACCEPTED);
    }

    /**
     * Request to delete payee based on valid accountNumber
     *
     * @param accountNumber
     * @return String msg
     */
    @DeleteMapping("/manage/deletePayee/{accountNumber}")
    public ResponseEntity<String> deletePayee(@PathVariable int accountNumber) {
        log.info("Entered deletePayee "+PayeeController.class);
        String payeeDeletionConfirmation = managePayeeService.deletePayee(accountNumber);
        return new ResponseEntity<String>(payeeDeletionConfirmation, HttpStatus.ACCEPTED);

    }

}
