package com.bank.it.payees.dto.mapper;

import com.bank.it.payees.constants.KafkaConstants;
import com.bank.it.payees.dto.request.PayeeRequest;
import com.bank.it.payees.dto.response.PayeeResponse;
import com.bank.it.payees.entity.PayeeEntity;
import com.bank.it.payees.entity.PayeeUpdateEntity;
import com.bank.it.payees.model.Payee;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

public class PayeeMapperImpl implements PayeeMapper{

    @Autowired
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private LocalDate today;
    @Override
    public PayeeEntity fromRequestToEntity(PayeeRequest payeeRequest) {
        PayeeEntity payeeEntity = new PayeeEntity();

        payeeEntity.setId(payeeRequest.getId());
        payeeEntity.setAccountNumber(payeeRequest.getAccountNumber());
        payeeEntity.setAccountName(payeeRequest.getAccountName());
        payeeEntity.setAddress(payeeRequest.getAddress());
        payeeEntity.setMobileNumber(payeeRequest.getMobileNumber());
        payeeEntity.setNickName(payeeRequest.getNickName());
        payeeEntity.setBranchCode(payeeRequest.getBranchCode());
        payeeEntity.setBranchName(payeeRequest.getBranchName());
        payeeEntity.setNationality(payeeRequest.getNationality());
        payeeEntity.setDailyTxnLimit(payeeRequest.getDailyTxnLimit());

        return payeeEntity;
    }

    /**
     * @param payeeEntity
     * @return
     */
    @Override
    public PayeeResponse fromEntityToResponse(PayeeEntity payeeEntity) {
        PayeeResponse payeeResponse = new PayeeResponse();

        payeeResponse.setId(payeeEntity.getId());
        payeeResponse.setAccountNumber(payeeEntity.getAccountNumber());
        payeeResponse.setAccountName(payeeEntity.getAccountName());
        payeeResponse.setAddress(payeeEntity.getAddress());
        payeeResponse.setMobileNumber(payeeEntity.getMobileNumber());
        payeeResponse.setNickName(payeeEntity.getNickName());
        payeeResponse.setBranchCode(payeeEntity.getBranchCode());
        payeeResponse.setBranchName(payeeEntity.getBranchName());
        payeeResponse.setNationality(payeeEntity.getNationality());
        payeeResponse.setDailyTxnLimit(payeeEntity.getDailyTxnLimit());
        return payeeResponse;
    }

    /**
     * @param payeeEntity
     * @return
     */
    @Override
    public Payee fromEntityToPayee(PayeeEntity payeeEntity) {
        Payee payee = new Payee();
        today = LocalDate.now();

        payee.setAccountName(payeeEntity.getAccountName());
        payee.setAccountNumber(payeeEntity.getAccountNumber());
        payee.setMobileNumber(payeeEntity.getMobileNumber());
        payee.setBranchCode(payeeEntity.getBranchCode());
        payee.setBranchName(payeeEntity.getBranchName());
        payee.setStatus(KafkaConstants.PAYEE_UPDATE_STATUS);
        payee.setUpdatedDate(today.toString());

        return payee;
    }

    /**
     * @param payee
     * @return
     */
    @Override
    public PayeeUpdateEntity fromPayeeToPayeeUpdateEntity(Payee payee) {

        PayeeUpdateEntity payeeUpdateEntity = new PayeeUpdateEntity();

        payeeUpdateEntity.setAccountNumber(payee.getAccountNumber());
        payeeUpdateEntity.setAccountName(payee.getAccountName());
        payeeUpdateEntity.setMobileNumber(payee.getMobileNumber());
        payeeUpdateEntity.setBranchCode(payee.getBranchCode());
        payeeUpdateEntity.setBranchName(payee.getBranchName());
        payeeUpdateEntity.setUpdatedDate(payee.getUpdatedDate());
        payeeUpdateEntity.setStatus(payee.getStatus());

        return payeeUpdateEntity;
    }

    /**
     * @param
     * @return
     */
    @Override
    public List<PayeeResponse> fromEntityListToResponseList(List<PayeeEntity> payeeEntityList) {

        List<PayeeResponse> payeeResponseStream = payeeEntityList.stream().map(
                (payeeEntity)-> MAPPER.fromEntityToResponse(payeeEntity)
                ).collect(Collectors.toList());

        return payeeResponseStream;
    }



}
