package com.bank.it.payees.exception;

import com.bank.it.payees.exception.custom.PayeeCustomException;
import com.bank.it.payees.exception.custom.PayeeNotFoundException;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;


import java.util.HashMap;
import java.util.Map;

@RestControllerAdvice
public class PayeeExceptionHandler {

    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ExceptionHandler(MethodArgumentNotValidException.class)
    public Map<String, String> handleInvalidArgument(MethodArgumentNotValidException ex){
    Map<String, String> errorMap = new HashMap<>();
        ex.getBindingResult().getFieldErrors().forEach(error -> {
            errorMap.put(error.getField(), error.getDefaultMessage());
        }
        );
        return errorMap;
    }

    @ResponseStatus(HttpStatus.NOT_FOUND)
    @ExceptionHandler(PayeeNotFoundException.class)
    public Object handlePayeeNotFound(PayeeNotFoundException pe){
        PayeeCustomException payeeCustomException = new PayeeCustomException(
                pe.getMessage(),
                pe.getCause(),
                HttpStatus.NOT_FOUND
        );
        return payeeCustomException;
    }
}
